@@ -123,7 +123,7 @@ class Client(object):
         self._handle_token(r.headers)
         return r
 
-    def request(self, method, url, **kwargs):
+    def request(self, method, url, auth=None, **kwargs):
         """Executes an Http request.
 
         :param method: The Http method.
